@@ -2,8 +2,12 @@
 #include <sys/types.h>
 #include <sys/wait.h>
 
+#ifdef __SVR4_I386_ABI_L1__
+#define wait4	__wait4
+#else
 static inline
 _syscall4(__pid_t,wait4,__pid_t,pid,__WAIT_STATUS_DEFN,status,int,options,struct rusage *,ru)
+#endif
 
 __pid_t
 __wait3(__WAIT_STATUS_DEFN wait_stat, int options, struct rusage *reserved)
