@@ -12,8 +12,7 @@ but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details. */
 
-#include <fp.h>
-#include "mathl.h"
+#include  <math.h>
 
 long double
 floorl (long double x)
