@@ -319,7 +319,7 @@ __yp_dobind (char *dom, struct dom_binding **ypdb)
       tv.tv_usec = 0;
       r = clnt_call (client,
                      YPBINDPROC_DOMAIN,
-                     (xdrproc_t)xdr_domainname, dom,
+                     (xdrproc_t)xdr_domainname, (char *)&dom,
                      (xdrproc_t)xdr_ypbind_resp, (char *)&ypbr,
                      tv);
       if (r != RPC_SUCCESS)
